@@ -1,6 +1,10 @@
 import re
 import textwrap
-import unittest
+
+try:
+    import unittest2 as unittest
+except ImportError:
+    import unittest
 
 from . import fixtures
 from importlib_metadata import (
@@ -12,6 +16,7 @@ from importlib_metadata import (
 class APITests(
         fixtures.EggInfoPkg,
         fixtures.DistInfoPkg,
+        fixtures.DistInfoPkgWithDot,
         fixtures.EggInfoFile,
         unittest.TestCase):
 
@@ -31,6 +36,12 @@ class APITests(
         with self.assertRaises(PackageNotFoundError):
             distribution('does-not-exist')
 
+    def test_name_normalization(self):
+        names = 'pkg.dot', 'pkg_dot', 'pkg-dot', 'pkg..dot', 'Pkg.Dot'
+        for name in names:
+            with self.subTest(name):
+                assert distribution(name).metadata['Name'] == 'pkg.dot'
+
     def test_for_top_level(self):
         self.assertEqual(
             distribution('egginfo-pkg').read_text('top_level.txt').strip(),
@@ -146,6 +157,14 @@ class APITests(
         assert deps == expected
 
 
+class LegacyDots(fixtures.DistInfoPkgWithDotLegacy, unittest.TestCase):
+    def test_name_normalization(self):
+        names = 'pkg.dot', 'pkg_dot', 'pkg-dot', 'pkg..dot', 'Pkg.Dot'
+        for name in names:
+            with self.subTest(name):
+                assert distribution(name).metadata['Name'] == 'pkg.dot'
+
+
 class OffSysPathTests(fixtures.DistInfoPkgOffPath, unittest.TestCase):
     def test_find_distributions_specified_path(self):
         dists = Distribution.discover(path=[str(self.site_dir)])
